﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;

namespace HeuristicLab.Persistence {
  [AttributeUsage(AttributeTargets.Class, AllowMultiple = false, Inherited = false)]
  public sealed class TransformerAttribute : Attribute {
    public Guid Guid { get; private set; }
    public uint Order { get; private set; }

    public TransformerAttribute(string guid, uint order) {
      Guid = new Guid(guid);
      Order = order;
    }

    public static bool IsTransformer(Type type) {
      return Attribute.IsDefined(type, typeof(TransformerAttribute), false);
    }
    public static TransformerAttribute GetTransformerAttribute(Type type) {
      return (TransformerAttribute)Attribute.GetCustomAttribute(type, typeof(TransformerAttribute), false);
    }
    public static Guid GetGuid(Type type) {
      return GetTransformerAttribute(type).Guid;
    }
    public static uint GetOrder(Type type) {
      return GetTransformerAttribute(type).Order;
    }
  }
}
